<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>Batchprocessing</name>
    <message>
        <location filename="../batchprocessing.cpp" line="42"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="42"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="159"/>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>MX Snapshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Snapshot location:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="206"/>
        <location filename="../mainwindow.cpp" line="321"/>
        <source>Snapshot name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>Select a different snapshot directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Optional customization</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="43"/>
        <source>Boot options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>Release date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="91"/>
        <source>Project name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>Release version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Release codename:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Location and ISO name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <location filename="../mainwindow.ui" line="370"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="412"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>All of the above</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="426"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Desktop</source>
        <translation>Asztal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>exclude network configurations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="467"/>
        <source>Networks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="538"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="515"/>
        <source>Type of snapshot:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="505"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>Edit Exclusion File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="618"/>
        <source>ISO compression scheme:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="866"/>
        <source>Display help </source>
        <translation>Súgó megjelenítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="869"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="876"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="733"/>
        <source>About this application</source>
        <translation>Az alkalmazásról</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="577"/>
        <source>sha512</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="604"/>
        <source>md5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="611"/>
        <source>Calculate checksums:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>About...</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="743"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="759"/>
        <source>Quit application</source>
        <translation>Kilépés az alkalmazásból</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="769"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="849"/>
        <source>Back</source>
        <translation>Vissza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <source>fastest, worst compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <source>fast, worse compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <source>slow, better compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="168"/>
        <source>best compromise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="169"/>
        <source>slowest, best compression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="197"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <location filename="../mainwindow.cpp" line="208"/>
        <source>Installing </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>Please wait.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <location filename="../mainwindow.cpp" line="332"/>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="313"/>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Snapshot will use the following settings:*</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>- Snapshot directory:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>- Kernel to be used:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>Final chance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="341"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="342"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>OK to start?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Shutdown computer when done.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>Could not create temporary directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>Edit Boot Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>Version: </source>
        <translation>Verzió:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="475"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="477"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="499"/>
        <source>Select Snapshot Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="518"/>
        <source>Confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>Are you sure you want to quit the application?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="50"/>
        <source>License</source>
        <translation>Liszensz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation>Változásbejegyzés</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="70"/>
        <source>&amp;Close</source>
        <translation>&amp;Bezár</translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="64"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Use CLI only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Output directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>Output filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>Or the full path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="78"/>
        <source>version, or path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="79"/>
        <source>Compression level options.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>Use quotes: &quot;-Xcompression-level &lt;level&gt;&quot;, or &quot;-Xalgorithm &lt;algorithm&gt;&quot;, or &quot;-Xhc&quot;, see mksquashfs man page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="81"/>
        <source>&quot;option&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>Skip calculating free space to see if the resulting ISO will fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>Exclude main folders, valid choices: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>one item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="92"/>
        <source>Compression format, valid choices: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="93"/>
        <source>format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="94"/>
        <source>Shutdown computer when done.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="113"/>
        <location filename="../main.cpp" line="122"/>
        <location filename="../main.cpp" line="153"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="133"/>
        <location filename="../main.cpp" line="160"/>
        <source>version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="139"/>
        <source>You must run this program as root.</source>
        <translation>Root felhasználóként kell futtatnia ezt a programot!</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="152"/>
        <location filename="../main.cpp" line="223"/>
        <location filename="../settings.cpp" line="208"/>
        <location filename="../settings.cpp" line="221"/>
        <location filename="../settings.cpp" line="572"/>
        <location filename="../settings.cpp" line="627"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="217"/>
        <location filename="../main.cpp" line="219"/>
        <location filename="../settings.cpp" line="216"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="86"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="107"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="203"/>
        <source>Could not find a usable kernel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="319"/>
        <source>Used space on / (root): </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="322"/>
        <source>estimated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="331"/>
        <source>Used space on /home: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="387"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="389"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="404"/>
        <source>Desktop</source>
        <translation>Asztal</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="405"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="406"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="407"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="408"/>
        <source>Networks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="409"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="411"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="567"/>
        <location filename="../settings.cpp" line="622"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="116"/>
        <source>Interrupted or failed to complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../work.cpp" line="85"/>
        <source>Cleaning...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="107"/>
        <location filename="../work.cpp" line="115"/>
        <location filename="../work.cpp" line="267"/>
        <source>Done</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="145"/>
        <location filename="../work.cpp" line="224"/>
        <location filename="../work.cpp" line="243"/>
        <location filename="../work.cpp" line="286"/>
        <location filename="../work.cpp" line="338"/>
        <location filename="../work.cpp" line="391"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="146"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="147"/>
        <source>You have %1 free space on %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="148"/>
        <source>If you are sure you have enough free space rerun the program with -o/--override-size option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="173"/>
        <source>Copying the new-iso filesystem...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="185"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="221"/>
        <source>Squashing filesystem...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="225"/>
        <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="241"/>
        <source>Creating CD/DVD image file...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="243"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="250"/>
        <source>Making hybrid iso</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="272"/>
        <source>Success</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="272"/>
        <source>MX Snapshot completed sucessfully!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="273"/>
        <source>Snapshot took %1 to finish.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="274"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="283"/>
        <source>Installing </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="286"/>
        <source>Could not install </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="296"/>
        <source>Calculating checksum...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="327"/>
        <source>Building new initrd...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="338"/>
        <source>Could not find %1 file, cannot continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="391"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="526"/>
        <source>Calculating total size of excluded files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="536"/>
        <source>Calculating size of root...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
